import getData from '../actions/getData.js';
import loadJson from '../utils/loadJson.js';

const env = JSON.stringify(getData('env'));

const params = `{
    ...config,
    env: {...${env}, ...config.env},
    paths: {
        wasm: 'cpp.wasm',
        data: 'cpp.data.txt'
    }
}`;

export default function exportWeb(bridgePath = null) {
    const bridgeExportFile = `${bridgePath}.exports.json`;
    let symbols = null;
    if (bridgePath) {
        symbols = loadJson(bridgeExportFile);
    }

    let symbolExportDefineString = '';
    let symbolExportAssignString = '';
    if (symbols && Array.isArray(symbols)) {
        symbolExportDefineString = symbols.map((s) => `export let ${s} = null;`).join('\n');
        symbolExportAssignString = symbols.map((s) => `${s} = m.${s};`).join('\n');
    }

    return `
export let AllSymbols = {};
${symbolExportDefineString}
export function initCppJs(config = {}) {
return new Promise(
    (resolve, reject) => import('/cpp.js').then(n => { return window.CppJs.initCppJs(${params})}).then(m => {
        AllSymbols = m;
        ${symbolExportAssignString}
        resolve(m);
    })
);
}
`;
}
